@@ -336,13 +336,14 @@ class PSMTemplate():
 
             return font_size
     
-    def add_note(self,note):
+    def add_note(self,note,counter_text=None):
         """Add note to the page
         
         :param note: Note
         :type note: str
+        :type counter_text: str
         """
-        self.notes.append(note)
+        self.notes.append({'note':note,'counter_text':counter_text})
     
     def add_footnote(self,footnote):
         """Add footnote to the page
@@ -372,8 +373,11 @@ class PSMTemplate():
         
         note_counter = 1
         for n in self.notes:
-            canvas.drawString((0.5)*cm,note_height-note_counter*self.note_font_size,f"{note_counter}.")
-            canvas.drawString((0.5+1)*cm,note_height-note_counter*self.note_font_size,n)
+            if n['counter_text'] == None:
+                canvas.drawString((0.5)*cm,note_height-note_counter*self.note_font_size,f"{note_counter}.")
+            else:
+                canvas.drawString((0.5)*cm,note_height-note_counter*self.note_font_size,f"{n['counter_text']}.")
+            canvas.drawString((0.5+1)*cm,note_height-note_counter*self.note_font_size,n['note'])
             note_counter = note_counter + 1
         canvas.restoreState()
         return True
@@ -860,7 +864,7 @@ if __name__ == "__main__":
     a3_landscape_temp = appA.new_page("Description Line 1","Description Line 2",size=A3,direction="landscape")
     a3_landscape_temp.add_figure("test/image/test.png")
     for i in range(0,5):
-        a3_landscape_temp.add_note(f"Note {i}")
+        a3_landscape_temp.add_note(f"Note {i}","1.")
     
     appA.save_temp_file = True
 
